@@ -511,6 +511,7 @@ def cleanUp():
             marker = ""
         for name in ["/usr/share/applications/eric6" + marker + ".desktop",
                      "/usr/share/appdata/eric6" + marker + ".appdata.xml",
+                     "/usr/share/metainfo/eric6" + marker + ".appdata.xml",
                      "/usr/share/applications/eric6_webbrowser" + marker +
                      ".desktop"]:
             if os.path.exists(name):
@@ -815,7 +816,7 @@ def installEric():
                 os.path.join(dst, "eric6_webbrowser" + marker + ".desktop"),
                 marker)
             dst = os.path.normpath(
-                os.path.join(distDir, "usr/share/appdata"))
+                os.path.join(distDir, "usr/share/metainfo"))
             if not os.path.exists(dst):
                 os.makedirs(dst)
             copyDesktopFile(
@@ -830,7 +831,12 @@ def installEric():
                 os.path.join(sourceDir, "eric6.desktop"),
                 "/usr/share/applications/eric6" + marker + ".desktop",
                 marker)
-            if os.path.exists("/usr/share/appdata"):
+            if os.path.exists("/usr/share/metainfo"):
+                copyDesktopFile(
+                    os.path.join(sourceDir, "eric6.appdata.xml"),
+                    "/usr/share/metainfo/eric6" + marker + ".appdata.xml",
+                    marker)
+            elif os.path.exists("/usr/share/appdata"):
                 copyDesktopFile(
                     os.path.join(sourceDir, "eric6.appdata.xml"),
                     "/usr/share/appdata/eric6" + marker + ".appdata.xml",
